<!DOCTYPE gui>
<gui name="kalarm" version="330" >
 <ToolBar noMerge="1" name="mainToolBar" >
  <Action name="new" />
  <Separator/>
  <Action name="copy" />
  <Action name="modify" />
  <Action name="delete" />
  <Separator/>
  <Action name="edit_undo" />
  <Action name="edit_redo" />
  <Separator/>
  <Action name="edit_find"/>
  <Spacer/>
  <Action name="hamburger_menu"/>
 </ToolBar>
 <MenuBar>
  <Menu name="file" >
   <text>&amp;File</text>
   <Action name="new" />
   <Action name="copy" />
   <Separator/>
   <Action name="createTemplate" />
   <Separator/>
   <Action name="templates" />
   <Action name="importAlarms" />
   <Action name="importBirthdays" />
   <Action name="exportAlarms" />
  </Menu>
  <Menu noMerge="1" name="edit" >
   <text>&amp;Edit</text>
   <Action name="edit_undo" />
   <Action name="edit_redo" />
   <Separator/>
   <Action name="modify" />
   <Action name="delete" />
   <Separator/>
   <Action name="edit_select_all" />
   <Action name="edit_deselect" />
   <Separator/>
   <Action name="edit_find" />
   <Action name="edit_find_next" />
   <Action name="edit_find_prev" />
  </Menu>
  <Menu name="view" >
   <text>&amp;View</text>
   <Action name="showArchivedAlarms" />
   <Action name="showInSystemTray" />
   <Separator/>
   <Action name="showResources" />
   <Action name="showDateSelector" />
   <Separator/>
   <Action name="spread" />
  </Menu>
  <Menu name="actions" >
   <text>&amp;Actions</text>
   <Action name="undelete" />
   <Action name="disable" />
   <Separator/>
   <Action name="alarmsEnable" />
   <Action name="refreshAlarms" />
   <Separator/>
   <Action name="wakeSuspend" />
   <Separator/>
   <Action name="stopAudio" />
  </Menu>
  <Menu noMerge="1" name="settings" >
   <text>&amp;Settings</text>
   <Action name="options_show_menubar"/>
   <Merge name="StandardToolBarMenuHandler" />
   <Separator/>
   <Action name="options_configure_keybinding" />
   <Action name="options_configure_notifications" />
   <Action name="options_configure_toolbars" />
   <Action name="options_configure" />
  </Menu>
 </MenuBar>
 <Menu name="listContext" >
  <Action name="new" />
  <Separator/>
  <Action name="copy" />
  <Action name="modify" />
  <Action name="delete" />
  <Separator/>
  <Action name="undelete" />
  <Action name="disable" />
  <Separator/>
  <Action name="createTemplate" />
  <Action name="export" />
 </Menu>
 <Menu name="resourceContext" >
  <Action name="resReload" />
  <Action name="resSave" />
  <Separator/>
  <Action name="resDetails" />
  <Action name="resEdit" />
  <Action name="resUpdate" />
  <Action name="resRemove" />
  <Action name="resDefault" />
  <Separator/>
  <Action name="resSetColour" />
  <Action name="resClearColour" />
  <Separator/>
  <Action name="resAdd" />
  <Action name="resImport" />
  <Action name="resExport" />
 </Menu>
</gui>
